@@ -90,7 +90,7 @@ def json_stdin( ) :
     data_in_list = sys.stdin.readlines( )
     data_in_json = "".join( data_in_list )
 
-    data_in = json_loads(data_in_json)
+    data_in = json_loads( data_in_json )
 
     return( data_in )
 
@@ -642,6 +642,37 @@ def file_tmprandom(  ) :
         f.write( json_encode( data ) )
     return( fp )
 
+
+def file_youngerthan( fp , ts ) :
+    fstat = file_stat( fp )
+    return( fstat.st_mtime > ts )
+
+
+def dir_scan( dp ) :
+
+    fps = [ ]
+    
+    if not dir_exists( dp ) :
+        s_log.write("files_scan dir does not exist!")
+        return( fps )
+
+    for root , dirs , files in os.walk( dp ) :
+        for f in files :
+            fps.append( os.path.join( root , f ) )
+
+    return( fps )
+
+
+def matched_substring( haystack , needles ) :
+
+    if( not needles ) : return( True )
+
+    for needle in needles :
+        if( needle in haystack ) :
+            return( True )
+
+    return( False )
+
 ################
 
 def thread_get_id( ) :
