@@ -259,7 +259,7 @@ def runner_omnibus( path_runner ) :
                         prc1.kill( )
                         break
 
-                    s_log.write(job_rping)
+                    #s_log.write(job_rping)
                 ##########
 
                 s_util.sleep( 3 )
@@ -267,7 +267,7 @@ def runner_omnibus( path_runner ) :
                 if ( s_util.uptime( ) - prc_starttime ) > 900 :
                     s_log.write( "prc_counter!!! KILL" )
                     prc1.kill( )
-                    
+
             prc1.join( )
             # -9 when kill, 1 when exception/error..? 0 is OK
             runner_exitcode = prc1.exitcode
